@@ -1,6 +1,9 @@
+# -*- coding: utf-8 -*-
+from __future__ import unicode_literals
+
 from json import dumps
-from github3.decorators import requires_auth
-from github3.models import GitHubCore
+from ..decorators import requires_auth
+from ..models import GitHubCore
 
 
 class Label(GitHubCore):
@@ -17,13 +20,9 @@ class Label(GitHubCore):
         #: Name of the label, e.g., 'bug'
         self.name = label.get('name')
 
-    def __eq__(self, label):
-        return self._api == label._api
+        self._uniq = self._api
 
-    def __ne__(self, label):
-        return self._api != label._api
-
-    def __repr__(self):
+    def _repr(self):
         return '<Label [{0}]>'.format(self)
 
     def __str__(self):
